@@ -1,9 +1,17 @@
 /*
- * Copyright (C) 1999-2002, 2004, 2005, 2007, 2010, 2011, 2013-2016  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * Permission to use, copy, modify, and/or distribute this software for any
+ * purpose with or without fee is hereby granted, provided that the above
+ * copyright notice and this permission notice appear in all copies.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
+ * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
+ * AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
+ * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
+ * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
+ * OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
+ * PERFORMANCE OF THIS SOFTWARE.
  */
 
 #ifndef NAMED_QUERY_H
@@ -58,20 +66,9 @@ struct ns_query {
 	unsigned int			dns64_aaaaoklen;
 	unsigned int			dns64_options;
 	unsigned int			dns64_ttl;
-	struct {
-		dns_db_t *      	db;
-		dns_zone_t *      	zone;
-		dns_dbnode_t *      	node;
-		dns_rdatatype_t   	qtype;
-		dns_name_t *		fname;
-		dns_fixedname_t		fixed;
-		isc_result_t		result;
-		dns_rdataset_t *	rdataset;
-		dns_rdataset_t *	sigrdataset;
-		isc_boolean_t		authoritative;
-		isc_boolean_t		is_zone;
-	} redirect;
-
+	dns_keytag_t root_key_sentinel_keyid;
+	isc_boolean_t root_key_sentinel_is_ta;
+	isc_boolean_t root_key_sentinel_not_ta;
 };
 
 #define NS_QUERYATTR_RECURSIONOK	0x0001
@@ -91,7 +88,7 @@ struct ns_query {
 #define NS_QUERYATTR_DNS64		0x4000
 #define NS_QUERYATTR_DNS64EXCLUDE	0x8000
 #define NS_QUERYATTR_RRL_CHECKED	0x10000
-#define NS_QUERYATTR_REDIRECT		0x20000
+
 
 isc_result_t
 ns_query_init(ns_client_t *client);
