@@ -1,6 +1,5 @@
 /*
- * Copyright (C) 2004-2017  Internet Systems Consortium, Inc. ("ISC")
- * Copyright (C) 1999-2003  Internet Software Consortium.
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -82,6 +81,7 @@ struct ns_server {
 	isc_timer_t *		interface_timer;
 	isc_timer_t *		heartbeat_timer;
 	isc_timer_t *		pps_timer;
+	isc_timer_t *		tat_timer;
 
 	isc_uint32_t		interface_interval;
 	isc_uint32_t		heartbeat_interval;
@@ -113,6 +113,8 @@ struct ns_server {
 	dns_name_t		*session_keyname;
 	unsigned int		session_keyalg;
 	isc_uint16_t		session_keybits;
+	isc_boolean_t		interface_auto;
+	unsigned char		secret[32];	/*%< Source Identity Token */
 };
 
 #define NS_SERVER_MAGIC			ISC_MAGIC('S','V','E','R')
@@ -176,7 +178,19 @@ enum {
 	dns_nsstatscounter_udp = 41,
 	dns_nsstatscounter_tcp = 42,
 
-	dns_nsstatscounter_max = 43
+	dns_nsstatscounter_nsidopt = 43,
+	dns_nsstatscounter_expireopt = 44,
+	dns_nsstatscounter_otheropt = 45,
+
+	dns_nsstatscounter_sitopt = 46,
+	dns_nsstatscounter_sitbadsize = 47,
+	dns_nsstatscounter_sitbadtime = 48,
+	dns_nsstatscounter_sitnomatch = 49,
+	dns_nsstatscounter_sitmatch = 50,
+	dns_nsstatscounter_sitnew = 51,
+	dns_nsstatscounter_keytagopt = 52,
+
+	dns_nsstatscounter_max = 53
 };
 
 void
@@ -202,6 +216,13 @@ ns_server_reloadwanted(ns_server_t *server);
  * is ignored.
  */
 
+void
+ns_server_scan_interfaces(ns_server_t *server);
+/*%<
+ * Trigger a interface scan.
+ * Must only be called when running under server->task.
+ */
+
 void
 ns_server_flushonshutdown(ns_server_t *server, isc_boolean_t flush);
 /*%<
@@ -346,7 +367,7 @@ ns_add_reserved_dispatch(ns_server_t *server, const isc_sockaddr_t *addr);
  * Enable or disable dnssec validation.
  */
 isc_result_t
-ns_server_validation(ns_server_t *server, isc_lex_t *lex);
+ns_server_validation(ns_server_t *server, isc_lex_t *lex, isc_buffer_t *text);
 
 /*%
  * Add a zone to a running process
@@ -365,4 +386,11 @@ ns_server_del_zone(ns_server_t *server, isc_lex_t *lex, isc_buffer_t *text);
  */
 isc_result_t
 ns_server_signing(ns_server_t *server, isc_lex_t *lex, isc_buffer_t *text);
+
+/*%
+ * Lists status information for a given zone (e.g., name, type, files,
+ * load time, expiry, etc).
+ */
+isc_result_t
+ns_server_zonestatus(ns_server_t *server, isc_lex_t *lex, isc_buffer_t *text);
 #endif /* NAMED_SERVER_H */
