@@ -1,9 +1,17 @@
 /*
- * Copyright (C) 1999-2001, 2004-2007, 2011, 2013-2017  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * Permission to use, copy, modify, and/or distribute this software for any
+ * purpose with or without fee is hereby granted, provided that the above
+ * copyright notice and this permission notice appear in all copies.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
+ * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
+ * AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
+ * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
+ * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
+ * OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
+ * PERFORMANCE OF THIS SOFTWARE.
  */
 
 /* $Id: logconf.c,v 1.45 2011/03/05 23:52:29 tbox Exp $ */
@@ -194,12 +202,10 @@ channel_fromconf(const cfg_obj_t *channel, isc_logconfig_t *logconfig)
 		const cfg_obj_t *printcat = NULL;
 		const cfg_obj_t *printsev = NULL;
 		const cfg_obj_t *printtime = NULL;
-		const cfg_obj_t *buffered = NULL;
 
 		(void)cfg_map_get(channel, "print-category", &printcat);
 		(void)cfg_map_get(channel, "print-severity", &printsev);
 		(void)cfg_map_get(channel, "print-time", &printtime);
-		(void)cfg_map_get(channel, "buffered", &buffered);
 
 		if (printcat != NULL && cfg_obj_asboolean(printcat))
 			flags |= ISC_LOG_PRINTCATEGORY;
@@ -207,8 +213,6 @@ channel_fromconf(const cfg_obj_t *channel, isc_logconfig_t *logconfig)
 			flags |= ISC_LOG_PRINTTIME;
 		if (printsev != NULL && cfg_obj_asboolean(printsev))
 			flags |= ISC_LOG_PRINTLEVEL;
-		if (buffered != NULL && cfg_obj_asboolean(buffered))
-			flags |= ISC_LOG_BUFFERED;
 	}
 
 	level = ISC_LOG_INFO;
