@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -53,8 +53,10 @@
 #include <unistd.h>
 
 #include <isc/commandline.h>
+#include <isc/print.h>
 #include <isc/result.h>
 #include <isc/types.h>
+#include <isc/util.h>
 
 #include <pk11/pk11.h>
 #include <pk11/result.h>
@@ -64,16 +66,23 @@
 #endif
 
 #ifndef HAVE_CLOCK_GETTIME
+
+#include <sys/time.h>
+
 #ifndef CLOCK_REALTIME
 #define CLOCK_REALTIME 0
 #endif
 
-int
+static int clock_gettime(int32_t id, struct timespec *tp);
+
+static int
 clock_gettime(int32_t id, struct timespec *tp)
 {
 	struct timeval tv;
 	int result;
 
+	UNUSED(id);
+
 	result = gettimeofday(&tv, NULL);
 	if (result)
 		return (result);
