@@ -19,6 +19,8 @@
 #
 
 rm -f dig.out.ns2
+rm -f dig.out.expire
+rm -f sed.out.*
 rm -f */named.memstats
 rm -f */named.run
 rm -f */named.conf
