@@ -44,13 +44,6 @@ then
 	echo_i "failed"; status=`expr $status + 1`;
 fi
 
-echo_i "bad OPT option"
-$PERL formerr.pl -a 10.53.0.1 -p ${PORT} badoptoption > badoptoption.out
-ans=`grep got: badoptoption.out`
-if [ "${ans}" != "got: 00008001000100000000000100000100020000291000000000000000" ];
-then
-	echo_i "failed"; status=`expr $status + 1`;
-fi
-
 echo_i "exit status: $status"
+
 [ $status -eq 0 ] || exit 1
