@@ -14,7 +14,7 @@
 # OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 # PERFORMANCE OF THIS SOFTWARE.
 
-# $Id$
+# $Id: tests.sh,v 1.22 2012/02/03 23:46:58 tbox Exp $
 
 SYSTEMTESTTOP=..
 . $SYSTEMTESTTOP/conf.sh
@@ -44,7 +44,7 @@ do
 	grep ' running$' lwresd1/lwresd.run > /dev/null && break
 	sleep 1
 done
-./lwtest || ret=1
+$LWTEST || ret=1
 if [ $ret != 0 ]; then
 	echo "I:failed"
 fi
@@ -63,7 +63,7 @@ do
 	grep ' running$' lwresd1/lwresd.run > /dev/null && break
 	sleep 1
 done
-./lwtest || ret=1
+$LWTEST || ret=1
 if [ $ret != 0 ]; then
 	echo "I:failed"
 fi
@@ -82,7 +82,7 @@ do
 	grep ' running$' lwresd1/lwresd.run > /dev/null && break
 	sleep 1
 done
-./lwtest -nosearch || ret=1
+$LWTEST -nosearch || ret=1
 if [ $ret != 0 ]; then
 	echo "I:failed"
 fi
