@@ -38,10 +38,33 @@ if $test_fixed; then
     for i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16
     do
     $DIGCMD @10.53.0.1 fixed.example > dig.out.fixed || ret=1
-    cmp -s dig.out.fixed dig.out.fixed.good || ret=1
+    $DIFF dig.out.fixed dig.out.fixed.good >/dev/null || ret=1
     done
     if [ $ret != 0 ]; then echo_i "failed"; fi
     status=`expr $status + $ret`
+else
+    echo_i "Checking order fixed behaves as cyclic when disabled (master)"
+    ret=0
+    matches=0
+    for i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20
+    do
+        j=`expr $i % 4`
+	$DIGCMD @10.53.0.1 fixed.example > dig.out.fixed  || ret=1
+        if [ $i -le 4 ]; then
+            cp dig.out.fixed dig.out.$j
+        else
+            $DIFF dig.out.fixed dig.out.$j >/dev/null && matches=`expr $matches + 1`
+        fi
+    done
+    $DIFF dig.out.0 dig.out.1 >/dev/null && ret=1
+    $DIFF dig.out.0 dig.out.2 >/dev/null && ret=1
+    $DIFF dig.out.0 dig.out.3 >/dev/null && ret=1
+    $DIFF dig.out.1 dig.out.2 >/dev/null && ret=1
+    $DIFF dig.out.1 dig.out.3 >/dev/null && ret=1
+    $DIFF dig.out.2 dig.out.3 >/dev/null && ret=1
+    if [ $matches -ne 16 ]; then ret=1; fi
+    if [ $ret != 0 ]; then echo_i "failed"; fi
+    status=`expr $status + $ret`
 fi
 
 #
@@ -57,15 +80,15 @@ do
     if [ $i -le 4 ]; then
         cp dig.out.cyclic dig.out.$j
     else
-        cmp -s dig.out.cyclic dig.out.$j && matches=`expr $matches + 1`
+        $DIFF dig.out.cyclic dig.out.$j >/dev/null && matches=`expr $matches + 1`
     fi
 done
-cmp -s dig.out.0 dig.out.1 && ret=1
-cmp -s dig.out.0 dig.out.2 && ret=1
-cmp -s dig.out.0 dig.out.3 && ret=1
-cmp -s dig.out.1 dig.out.2 && ret=1
-cmp -s dig.out.1 dig.out.3 && ret=1
-cmp -s dig.out.2 dig.out.3 && ret=1
+$DIFF dig.out.0 dig.out.1 >/dev/null && ret=1
+$DIFF dig.out.0 dig.out.2 >/dev/null && ret=1
+$DIFF dig.out.0 dig.out.3 >/dev/null && ret=1
+$DIFF dig.out.1 dig.out.2 >/dev/null && ret=1
+$DIFF dig.out.1 dig.out.3 >/dev/null && ret=1
+$DIFF dig.out.2 dig.out.3 >/dev/null && ret=1
 if [ $matches -ne 16 ]; then ret=1; fi
 if [ $ret != 0 ]; then echo_i "failed"; fi
 status=`expr $status + $ret`
@@ -83,15 +106,15 @@ do
     if [ $i -le 4 ]; then
         cp dig.out.cyclic2 dig.out.$j
     else
-        cmp -s dig.out.cyclic2 dig.out.$j && matches=`expr $matches + 1`
+        $DIFF dig.out.cyclic2 dig.out.$j >/dev/null && matches=`expr $matches + 1`
     fi
 done
-cmp -s dig.out.0 dig.out.1 && ret=1
-cmp -s dig.out.0 dig.out.2 && ret=1
-cmp -s dig.out.0 dig.out.3 && ret=1
-cmp -s dig.out.1 dig.out.2 && ret=1
-cmp -s dig.out.1 dig.out.3 && ret=1
-cmp -s dig.out.2 dig.out.3 && ret=1
+$DIFF dig.out.0 dig.out.1 >/dev/null && ret=1
+$DIFF dig.out.0 dig.out.2 >/dev/null && ret=1
+$DIFF dig.out.0 dig.out.3 >/dev/null && ret=1
+$DIFF dig.out.1 dig.out.2 >/dev/null && ret=1
+$DIFF dig.out.1 dig.out.3 >/dev/null && ret=1
+$DIFF dig.out.2 dig.out.3 >/dev/null && ret=1
 if [ $matches -ne 16 ]; then ret=1; fi
 if [ $ret != 0 ]; then echo_i "failed"; fi
 status=`expr $status + $ret`
@@ -107,7 +130,7 @@ do
     match=0
     for j in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24
     do
-        eval "cmp -s dig.out.random dig.out.random.good$j && match$j=1 match=1"
+	eval "$DIFF dig.out.random dig.out.random.good$j >/dev/null && match$j=1 match=1"
 	if [ $match -eq 1 ]; then break; fi
     done
     if [ $match -eq 0 ]; then ret=1; fi
@@ -131,7 +154,7 @@ if $test_fixed; then
     for i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16
     do
     $DIGCMD @10.53.0.2 fixed.example > dig.out.fixed || ret=1
-    cmp -s dig.out.fixed dig.out.fixed.good || ret=1
+    $DIFF dig.out.fixed dig.out.fixed.good || ret=1
     done
     if [ $ret != 0 ]; then echo_i "failed"; fi
     status=`expr $status + $ret`
@@ -150,15 +173,15 @@ do
     if [ $i -le 4 ]; then
         cp dig.out.cyclic dig.out.$j
     else
-        cmp -s dig.out.cyclic dig.out.$j && matches=`expr $matches + 1`
+        $DIFF dig.out.cyclic dig.out.$j >/dev/null && matches=`expr $matches + 1`
     fi
 done
-cmp -s dig.out.0 dig.out.1 && ret=1
-cmp -s dig.out.0 dig.out.2 && ret=1
-cmp -s dig.out.0 dig.out.3 && ret=1
-cmp -s dig.out.1 dig.out.2 && ret=1
-cmp -s dig.out.1 dig.out.3 && ret=1
-cmp -s dig.out.2 dig.out.3 && ret=1
+$DIFF dig.out.0 dig.out.1 >/dev/null && ret=1
+$DIFF dig.out.0 dig.out.2 >/dev/null && ret=1
+$DIFF dig.out.0 dig.out.3 >/dev/null && ret=1
+$DIFF dig.out.1 dig.out.2 >/dev/null && ret=1
+$DIFF dig.out.1 dig.out.3 >/dev/null && ret=1
+$DIFF dig.out.2 dig.out.3 >/dev/null && ret=1
 if [ $matches -ne 16 ]; then ret=1; fi
 if [ $ret != 0 ]; then echo_i "failed"; fi
 status=`expr $status + $ret`
@@ -176,15 +199,15 @@ do
     if [ $i -le 4 ]; then
         cp dig.out.cyclic2 dig.out.$j
     else
-        cmp -s dig.out.cyclic2 dig.out.$j && matches=`expr $matches + 1`
+        $DIFF dig.out.cyclic2 dig.out.$j >/dev/null && matches=`expr $matches + 1`
     fi
 done
-cmp -s dig.out.0 dig.out.1 && ret=1
-cmp -s dig.out.0 dig.out.2 && ret=1
-cmp -s dig.out.0 dig.out.3 && ret=1
-cmp -s dig.out.1 dig.out.2 && ret=1
-cmp -s dig.out.1 dig.out.3 && ret=1
-cmp -s dig.out.2 dig.out.3 && ret=1
+$DIFF dig.out.0 dig.out.1 >/dev/null && ret=1
+$DIFF dig.out.0 dig.out.2 >/dev/null && ret=1
+$DIFF dig.out.0 dig.out.3 >/dev/null && ret=1
+$DIFF dig.out.1 dig.out.2 >/dev/null && ret=1
+$DIFF dig.out.1 dig.out.3 >/dev/null && ret=1
+$DIFF dig.out.2 dig.out.3 >/dev/null && ret=1
 if [ $matches -ne 16 ]; then ret=1; fi
 if [ $ret != 0 ]; then echo_i "failed"; fi
 status=`expr $status + $ret`
@@ -201,7 +224,7 @@ do
     match=0
     for j in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24
     do
-	eval "cmp -s dig.out.random dig.out.random.good$j && match$j=1 match=1"
+	eval "$DIFF dig.out.random dig.out.random.good$j >/dev/null && match$j=1 match=1"
 	if [ $match -eq 1 ]; then break; fi
     done
     if [ $match -eq 0 ]; then ret=1; fi
@@ -241,7 +264,7 @@ if $test_fixed; then
     for i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16
     do
     $DIGCMD @10.53.0.2 fixed.example > dig.out.fixed || ret=1
-    cmp -s dig.out.fixed dig.out.fixed.good || ret=1
+    $DIFF dig.out.fixed dig.out.fixed.good || ret=1
     done
     if [ $ret != 0 ]; then echo_i "failed"; fi
     status=`expr $status + $ret`
@@ -260,15 +283,15 @@ do
     if [ $i -le 4 ]; then
         cp dig.out.cyclic dig.out.$j
     else
-        cmp -s dig.out.cyclic dig.out.$j && matches=`expr $matches + 1`
+        $DIFF dig.out.cyclic dig.out.$j >/dev/null && matches=`expr $matches + 1`
     fi
 done
-cmp -s dig.out.0 dig.out.1 && ret=1
-cmp -s dig.out.0 dig.out.2 && ret=1
-cmp -s dig.out.0 dig.out.3 && ret=1
-cmp -s dig.out.1 dig.out.2 && ret=1
-cmp -s dig.out.1 dig.out.3 && ret=1
-cmp -s dig.out.2 dig.out.3 && ret=1
+$DIFF dig.out.0 dig.out.1 >/dev/null && ret=1
+$DIFF dig.out.0 dig.out.2 >/dev/null && ret=1
+$DIFF dig.out.0 dig.out.3 >/dev/null && ret=1
+$DIFF dig.out.1 dig.out.2 >/dev/null && ret=1
+$DIFF dig.out.1 dig.out.3 >/dev/null && ret=1
+$DIFF dig.out.2 dig.out.3 >/dev/null && ret=1
 if [ $matches -ne 16 ]; then ret=1; fi
 if [ $ret != 0 ]; then echo_i "failed"; fi
 status=`expr $status + $ret`
@@ -286,15 +309,15 @@ do
     if [ $i -le 4 ]; then
         cp dig.out.cyclic2 dig.out.$j
     else
-        cmp -s dig.out.cyclic2 dig.out.$j && matches=`expr $matches + 1`
+        $DIFF dig.out.cyclic2 dig.out.$j >/dev/null && matches=`expr $matches + 1`
     fi
 done
-cmp -s dig.out.0 dig.out.1 && ret=1
-cmp -s dig.out.0 dig.out.2 && ret=1
-cmp -s dig.out.0 dig.out.3 && ret=1
-cmp -s dig.out.1 dig.out.2 && ret=1
-cmp -s dig.out.1 dig.out.3 && ret=1
-cmp -s dig.out.2 dig.out.3 && ret=1
+$DIFF dig.out.0 dig.out.1 >/dev/null && ret=1
+$DIFF dig.out.0 dig.out.2 >/dev/null && ret=1
+$DIFF dig.out.0 dig.out.3 >/dev/null && ret=1
+$DIFF dig.out.1 dig.out.2 >/dev/null && ret=1
+$DIFF dig.out.1 dig.out.3 >/dev/null && ret=1
+$DIFF dig.out.2 dig.out.3 >/dev/null && ret=1
 if [ $matches -ne 16 ]; then ret=1; fi
 if [ $ret != 0 ]; then echo_i "failed"; fi
 status=`expr $status + $ret`
@@ -311,7 +334,7 @@ do
 	match=0
 	for j in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24
 	do
-		eval "cmp -s dig.out.random dig.out.random.good$j && match$j=1 match=1"
+		eval "$DIFF dig.out.random dig.out.random.good$j >/dev/null && match$j=1 match=1"
 		if [ $match -eq 1 ]; then break; fi
 	done
 	if [ $match -eq 0 ]; then ret=1; fi
@@ -335,7 +358,7 @@ if $test_fixed; then
     for i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16
     do
     $DIGCMD @10.53.0.3 fixed.example > dig.out.fixed || ret=1
-    cmp -s dig.out.fixed dig.out.fixed.good || ret=1
+    $DIFF dig.out.fixed dig.out.fixed.good || ret=1
     done
     if [ $ret != 0 ]; then echo_i "failed"; fi
     status=`expr $status + $ret`
@@ -356,15 +379,15 @@ do
     if [ $i -le 4 ]; then
         cp dig.out.cyclic dig.out.$j
     else
-        cmp -s dig.out.cyclic dig.out.$j && matches=`expr $matches + 1`
+        $DIFF dig.out.cyclic dig.out.$j >/dev/null && matches=`expr $matches + 1`
     fi
 done
-cmp -s dig.out.0 dig.out.1 && ret=1
-cmp -s dig.out.0 dig.out.2 && ret=1
-cmp -s dig.out.0 dig.out.3 && ret=1
-cmp -s dig.out.1 dig.out.2 && ret=1
-cmp -s dig.out.1 dig.out.3 && ret=1
-cmp -s dig.out.2 dig.out.3 && ret=1
+$DIFF dig.out.0 dig.out.1 >/dev/null && ret=1
+$DIFF dig.out.0 dig.out.2 >/dev/null && ret=1
+$DIFF dig.out.0 dig.out.3 >/dev/null && ret=1
+$DIFF dig.out.1 dig.out.2 >/dev/null && ret=1
+$DIFF dig.out.1 dig.out.3 >/dev/null && ret=1
+$DIFF dig.out.2 dig.out.3 >/dev/null && ret=1
 if [ $matches -ne 16 ]; then ret=1; fi
 if [ $ret != 0 ]; then echo_i "failed"; fi
 status=`expr $status + $ret`
@@ -384,15 +407,15 @@ do
     if [ $i -le 4 ]; then
         cp dig.out.cyclic2 dig.out.$j
     else
-        cmp -s dig.out.cyclic2 dig.out.$j && matches=`expr $matches + 1`
+        $DIFF dig.out.cyclic2 dig.out.$j >/dev/null && matches=`expr $matches + 1`
     fi
 done
-cmp -s dig.out.0 dig.out.1 && ret=1
-cmp -s dig.out.0 dig.out.2 && ret=1
-cmp -s dig.out.0 dig.out.3 && ret=1
-cmp -s dig.out.1 dig.out.2 && ret=1
-cmp -s dig.out.1 dig.out.3 && ret=1
-cmp -s dig.out.2 dig.out.3 && ret=1
+$DIFF dig.out.0 dig.out.1 >/dev/null && ret=1
+$DIFF dig.out.0 dig.out.2 >/dev/null && ret=1
+$DIFF dig.out.0 dig.out.3 >/dev/null && ret=1
+$DIFF dig.out.1 dig.out.2 >/dev/null && ret=1
+$DIFF dig.out.1 dig.out.3 >/dev/null && ret=1
+$DIFF dig.out.2 dig.out.3 >/dev/null && ret=1
 if [ $matches -ne 16 ]; then ret=1; fi
 if [ $ret != 0 ]; then echo_i "failed"; fi
 status=`expr $status + $ret`
@@ -409,7 +432,7 @@ do
 	match=0
 	for j in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24
 	do
-		eval "cmp -s dig.out.random dig.out.random.good$j && match$j=1 match=1"
+		eval "$DIFF dig.out.random dig.out.random.good$j >/dev/null && match$j=1 match=1"
 		if [ $match -eq 1 ]; then break; fi
 	done
 	if [ $match -eq 0 ]; then ret=1; fi
@@ -435,7 +458,7 @@ do
 	match=0
 	for j in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24
 	do
-		eval "cmp -s dig.out.random dig.out.random.good$j && match$j=1 match=1"
+		eval "$DIFF dig.out.random dig.out.random.good$j >/dev/null && match$j=1 match=1"
 		if [ $match -eq 1 ]; then break; fi
 	done
 	if [ $match -eq 0 ]; then ret=1; fi
