@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# Copyright (C) 2005-2007, 2012  Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) Internet Systems Consortium, Inc. ("ISC")
 #
 # Permission to use, copy, modify, and/or distribute this software for any
 # purpose with or without fee is hereby granted, provided that the above
@@ -14,12 +14,13 @@
 # OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 # PERFORMANCE OF THIS SOFTWARE.
 
-# $Id: clean.sh,v 1.6 2007/09/26 03:22:44 marka Exp $
-
 #
 # Clean up after tsig tests.
 #
 
 rm -f dig.out.*
 rm -f */named.memstats
+rm -f */named.conf
 rm -f */named.run
+rm -f Kexample.net.+163+*
+rm -f keygen.out?
