@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -29,7 +29,7 @@ fromtext_lp(ARGS_FROMTEXT) {
 	dns_name_t name;
 	isc_buffer_t buffer;
 
-	REQUIRE(type == 107);
+	REQUIRE(type == dns_rdatatype_lp);
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -46,7 +46,8 @@ fromtext_lp(ARGS_FROMTEXT) {
 
 	dns_name_init(&name, NULL);
 	buffer_fromregion(&buffer, &token.value.as_region);
-	origin = (origin != NULL) ? origin : dns_rootname;
+	if (origin == NULL)
+		origin = dns_rootname;
 	return (dns_name_fromtext(&name, &buffer, origin, options, target));
 }
 
@@ -59,7 +60,7 @@ totext_lp(ARGS_TOTEXT) {
 	char buf[sizeof("64000")];
 	unsigned short num;
 
-	REQUIRE(rdata->type == 107);
+	REQUIRE(rdata->type == dns_rdatatype_lp);
 	REQUIRE(rdata->length != 0);
 
 	dns_name_init(&name, NULL);
@@ -68,7 +69,7 @@ totext_lp(ARGS_TOTEXT) {
 	dns_rdata_toregion(rdata, &region);
 	num = uint16_fromregion(&region);
 	isc_region_consume(&region, 2);
-	sprintf(buf, "%u", num);
+	snprintf(buf, sizeof(buf), "%u", num);
 	RETERR(str_totext(buf, target));
 
 	RETERR(str_totext(" ", target));
@@ -83,7 +84,7 @@ fromwire_lp(ARGS_FROMWIRE) {
 	dns_name_t name;
 	isc_region_t sregion;
 
-	REQUIRE(type == 107);
+	REQUIRE(type == dns_rdatatype_lp);
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -103,7 +104,7 @@ fromwire_lp(ARGS_FROMWIRE) {
 static inline isc_result_t
 towire_lp(ARGS_TOWIRE) {
 
-	REQUIRE(rdata->type == 107);
+	REQUIRE(rdata->type == dns_rdatatype_lp);
 	REQUIRE(rdata->length != 0);
 
 	UNUSED(cctx);
@@ -118,7 +119,7 @@ compare_lp(ARGS_COMPARE) {
 
 	REQUIRE(rdata1->type == rdata2->type);
 	REQUIRE(rdata1->rdclass == rdata2->rdclass);
-	REQUIRE(rdata1->type == 107);
+	REQUIRE(rdata1->type == dns_rdatatype_lp);
 	REQUIRE(rdata1->length != 0);
 	REQUIRE(rdata2->length != 0);
 
@@ -133,7 +134,7 @@ fromstruct_lp(ARGS_FROMSTRUCT) {
 	dns_rdata_lp_t *lp = source;
 	isc_region_t region;
 
-	REQUIRE(type == 107);
+	REQUIRE(type == dns_rdatatype_lp);
 	REQUIRE(source != NULL);
 	REQUIRE(lp->common.rdtype == type);
 	REQUIRE(lp->common.rdclass == rdclass);
@@ -152,7 +153,7 @@ tostruct_lp(ARGS_TOSTRUCT) {
 	dns_rdata_lp_t *lp = target;
 	dns_name_t name;
 
-	REQUIRE(rdata->type == 107);
+	REQUIRE(rdata->type == dns_rdatatype_lp);
 	REQUIRE(target != NULL);
 	REQUIRE(rdata->length != 0);
 
@@ -176,7 +177,7 @@ freestruct_lp(ARGS_FREESTRUCT) {
 	dns_rdata_lp_t *lp = source;
 
 	REQUIRE(source != NULL);
-	REQUIRE(lp->common.rdtype == 107);
+	REQUIRE(lp->common.rdtype == dns_rdatatype_lp);
 
 	if (lp->mctx == NULL)
 		return;
@@ -192,7 +193,7 @@ additionaldata_lp(ARGS_ADDLDATA) {
 	isc_region_t region;
 	isc_result_t result;
 
-	REQUIRE(rdata->type == 107);
+	REQUIRE(rdata->type == dns_rdatatype_lp);
 
 	dns_name_init(&name, offsets);
 	dns_rdata_toregion(rdata, &region);
@@ -209,7 +210,7 @@ static inline isc_result_t
 digest_lp(ARGS_DIGEST) {
 	isc_region_t region;
 
-	REQUIRE(rdata->type == 107);
+	REQUIRE(rdata->type == dns_rdatatype_lp);
 
 	dns_rdata_toregion(rdata, &region);
 	return ((digest)(arg, &region));
@@ -218,7 +219,7 @@ digest_lp(ARGS_DIGEST) {
 static inline isc_boolean_t
 checkowner_lp(ARGS_CHECKOWNER) {
 
-	REQUIRE(type == 107);
+	REQUIRE(type == dns_rdatatype_lp);
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -231,7 +232,7 @@ checkowner_lp(ARGS_CHECKOWNER) {
 static inline isc_boolean_t
 checknames_lp(ARGS_CHECKNAMES) {
 
-	REQUIRE(rdata->type == 107);
+	REQUIRE(rdata->type == dns_rdatatype_lp);
 
 	UNUSED(bad);
 	UNUSED(owner);
@@ -249,7 +250,7 @@ casecompare_lp(ARGS_COMPARE) {
 
 	REQUIRE(rdata1->type == rdata2->type);
 	REQUIRE(rdata1->rdclass == rdata2->rdclass);
-	REQUIRE(rdata1->type == 107);
+	REQUIRE(rdata1->type == dns_rdatatype_lp);
 	REQUIRE(rdata1->length != 0);
 	REQUIRE(rdata2->length != 0);
 
