@@ -1,8 +1,7 @@
 /*
- * Copyright (C) 2004  Internet Systems Consortium, Inc. ("ISC")
- * Copyright (C) 1998-2001  Internet Software Consortium.
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * Permission to use, copy, modify, and distribute this software for any
+ * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
  * copyright notice and this permission notice appear in all copies.
  *
@@ -15,7 +14,7 @@
  * PERFORMANCE OF THIS SOFTWARE.
  */
 
-/* $Id: mb_7.c,v 1.41.206.2 2004/03/06 08:14:06 marka Exp $ */
+/* $Id: mb_7.c,v 1.47 2009/12/04 22:06:37 tbox Exp $ */
 
 /* Reviewed: Wed Mar 15 17:31:26 PST 2000 by bwelling */
 
@@ -30,7 +29,7 @@ fromtext_mb(ARGS_FROMTEXT) {
 	dns_name_t name;
 	isc_buffer_t buffer;
 
-	REQUIRE(type == 7);
+	REQUIRE(type == dns_rdatatype_mb);
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -41,7 +40,8 @@ fromtext_mb(ARGS_FROMTEXT) {
 
 	dns_name_init(&name, NULL);
 	buffer_fromregion(&buffer, &token.value.as_region);
-	origin = (origin != NULL) ? origin : dns_rootname;
+	if (origin == NULL)
+		origin = dns_rootname;
 	RETTOK(dns_name_fromtext(&name, &buffer, origin, options, target));
 	return (ISC_R_SUCCESS);
 }
@@ -53,7 +53,7 @@ totext_mb(ARGS_TOTEXT) {
 	dns_name_t prefix;
 	isc_boolean_t sub;
 
-	REQUIRE(rdata->type == 7);
+	REQUIRE(rdata->type == dns_rdatatype_mb);
 	REQUIRE(rdata->length != 0);
 
 	dns_name_init(&name, NULL);
@@ -69,17 +69,17 @@ totext_mb(ARGS_TOTEXT) {
 
 static inline isc_result_t
 fromwire_mb(ARGS_FROMWIRE) {
-        dns_name_t name;
+	dns_name_t name;
 
-	REQUIRE(type == 7);
+	REQUIRE(type == dns_rdatatype_mb);
 
 	UNUSED(type);
 	UNUSED(rdclass);
 
 	dns_decompress_setmethods(dctx, DNS_COMPRESS_GLOBAL14);
 
-        dns_name_init(&name, NULL);
-        return (dns_name_fromwire(&name, source, dctx, options, target));
+	dns_name_init(&name, NULL);
+	return (dns_name_fromwire(&name, source, dctx, options, target));
 }
 
 static inline isc_result_t
@@ -88,7 +88,7 @@ towire_mb(ARGS_TOWIRE) {
 	dns_offsets_t offsets;
 	isc_region_t region;
 
-	REQUIRE(rdata->type == 7);
+	REQUIRE(rdata->type == dns_rdatatype_mb);
 	REQUIRE(rdata->length != 0);
 
 	dns_compress_setmethods(cctx, DNS_COMPRESS_GLOBAL14);
@@ -109,7 +109,7 @@ compare_mb(ARGS_COMPARE) {
 
 	REQUIRE(rdata1->type == rdata2->type);
 	REQUIRE(rdata1->rdclass == rdata2->rdclass);
-	REQUIRE(rdata1->type == 7);
+	REQUIRE(rdata1->type == dns_rdatatype_mb);
 	REQUIRE(rdata1->length != 0);
 	REQUIRE(rdata2->length != 0);
 
@@ -130,7 +130,7 @@ fromstruct_mb(ARGS_FROMSTRUCT) {
 	dns_rdata_mb_t *mb = source;
 	isc_region_t region;
 
-	REQUIRE(type == 7);
+	REQUIRE(type == dns_rdatatype_mb);
 	REQUIRE(source != NULL);
 	REQUIRE(mb->common.rdtype == type);
 	REQUIRE(mb->common.rdclass == rdclass);
@@ -148,7 +148,7 @@ tostruct_mb(ARGS_TOSTRUCT) {
 	dns_rdata_mb_t *mb = target;
 	dns_name_t name;
 
-	REQUIRE(rdata->type == 7);
+	REQUIRE(rdata->type == dns_rdatatype_mb);
 	REQUIRE(target != NULL);
 	REQUIRE(rdata->length != 0);
 
@@ -184,7 +184,7 @@ additionaldata_mb(ARGS_ADDLDATA) {
 	dns_offsets_t offsets;
 	isc_region_t region;
 
-	REQUIRE(rdata->type == 7);
+	REQUIRE(rdata->type == dns_rdatatype_mb);
 
 	dns_name_init(&name, offsets);
 	dns_rdata_toregion(rdata, &region);
@@ -198,7 +198,7 @@ digest_mb(ARGS_DIGEST) {
 	isc_region_t r;
 	dns_name_t name;
 
-	REQUIRE(rdata->type == 7);
+	REQUIRE(rdata->type == dns_rdatatype_mb);
 
 	dns_rdata_toregion(rdata, &r);
 	dns_name_init(&name, NULL);
@@ -210,7 +210,7 @@ digest_mb(ARGS_DIGEST) {
 static inline isc_boolean_t
 checkowner_mb(ARGS_CHECKOWNER) {
 
-	REQUIRE(type == 7);
+	REQUIRE(type == dns_rdatatype_mb);
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -222,7 +222,7 @@ checkowner_mb(ARGS_CHECKOWNER) {
 static inline isc_boolean_t
 checknames_mb(ARGS_CHECKNAMES) {
 
-	REQUIRE(rdata->type == 7);
+	REQUIRE(rdata->type == dns_rdatatype_mb);
 
 	UNUSED(rdata);
 	UNUSED(owner);
@@ -231,4 +231,9 @@ checknames_mb(ARGS_CHECKNAMES) {
 	return (ISC_TRUE);
 }
 
+static inline int
+casecompare_mb(ARGS_COMPARE) {
+	return (compare_mb(rdata1, rdata2));
+}
+
 #endif	/* RDATA_GENERIC_MB_7_C */
