@@ -1,6 +1,5 @@
 /*
- * Copyright (C) 2004, 2007, 2009  Internet Systems Consortium, Inc. ("ISC")
- * Copyright (C) 1999-2003  Internet Software Consortium.
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -15,7 +14,7 @@
  * PERFORMANCE OF THIS SOFTWARE.
  */
 
-/* $Id: a6_38.c,v 1.56 2009-12-04 22:06:37 tbox Exp $ */
+/* $Id: a6_38.c,v 1.56 2009/12/04 22:06:37 tbox Exp $ */
 
 /* RFC2874 */
 
@@ -37,8 +36,8 @@ fromtext_in_a6(ARGS_FROMTEXT) {
 	isc_buffer_t buffer;
 	isc_boolean_t ok;
 
-	REQUIRE(type == 38);
-	REQUIRE(rdclass == 1);
+	REQUIRE(type == dns_rdatatype_a6);
+	REQUIRE(rdclass == dns_rdataclass_in);
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -83,7 +82,8 @@ fromtext_in_a6(ARGS_FROMTEXT) {
 				      ISC_FALSE));
 	dns_name_init(&name, NULL);
 	buffer_fromregion(&buffer, &token.value.as_region);
-	origin = (origin != NULL) ? origin : dns_rootname;
+	if (origin == NULL)
+		origin = dns_rootname;
 	RETTOK(dns_name_fromtext(&name, &buffer, origin, options, target));
 	ok = ISC_TRUE;
 	if ((options & DNS_RDATA_CHECKNAMES) != 0)
@@ -107,22 +107,22 @@ totext_in_a6(ARGS_TOTEXT) {
 	dns_name_t prefix;
 	isc_boolean_t sub;
 
-	REQUIRE(rdata->type == 38);
-	REQUIRE(rdata->rdclass == 1);
+	REQUIRE(rdata->type == dns_rdatatype_a6);
+	REQUIRE(rdata->rdclass == dns_rdataclass_in);
 	REQUIRE(rdata->length != 0);
 
 	dns_rdata_toregion(rdata, &sr);
 	prefixlen = sr.base[0];
 	INSIST(prefixlen <= 128);
 	isc_region_consume(&sr, 1);
-	sprintf(buf, "%u", prefixlen);
+	snprintf(buf, sizeof(buf), "%u", prefixlen);
 	RETERR(str_totext(buf, target));
 	RETERR(str_totext(" ", target));
 
 	if (prefixlen != 128) {
 		octets = prefixlen/8;
 		memset(addr, 0, sizeof(addr));
-		memcpy(&addr[octets], sr.base, 16 - octets);
+		memmove(&addr[octets], sr.base, 16 - octets);
 		mask = 0xff >> (prefixlen % 8);
 		addr[octets] &= mask;
 		ar.base = addr;
@@ -150,8 +150,8 @@ fromwire_in_a6(ARGS_FROMWIRE) {
 	unsigned char mask;
 	dns_name_t name;
 
-	REQUIRE(type == 38);
-	REQUIRE(rdclass == 1);
+	REQUIRE(type == dns_rdatatype_a6);
+	REQUIRE(rdclass == dns_rdataclass_in);
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -199,8 +199,8 @@ towire_in_a6(ARGS_TOWIRE) {
 	unsigned char prefixlen;
 	unsigned char octets;
 
-	REQUIRE(rdata->type == 38);
-	REQUIRE(rdata->rdclass == 1);
+	REQUIRE(rdata->type == dns_rdatatype_a6);
+	REQUIRE(rdata->rdclass == dns_rdataclass_in);
 	REQUIRE(rdata->length != 0);
 
 	dns_compress_setmethods(cctx, DNS_COMPRESS_NONE);
@@ -232,8 +232,8 @@ compare_in_a6(ARGS_COMPARE) {
 
 	REQUIRE(rdata1->type == rdata2->type);
 	REQUIRE(rdata1->rdclass == rdata2->rdclass);
-	REQUIRE(rdata1->type == 38);
-	REQUIRE(rdata1->rdclass == 1);
+	REQUIRE(rdata1->type == dns_rdatatype_a6);
+	REQUIRE(rdata1->rdclass == dns_rdataclass_in);
 	REQUIRE(rdata1->length != 0);
 	REQUIRE(rdata2->length != 0);
 
@@ -283,8 +283,8 @@ fromstruct_in_a6(ARGS_FROMSTRUCT) {
 	isc_uint8_t first;
 	isc_uint8_t mask;
 
-	REQUIRE(type == 38);
-	REQUIRE(rdclass == 1);
+	REQUIRE(type == dns_rdatatype_a6);
+	REQUIRE(rdclass == dns_rdataclass_in);
 	REQUIRE(source != NULL);
 	REQUIRE(a6->common.rdtype == type);
 	REQUIRE(a6->common.rdclass == rdclass);
@@ -326,8 +326,8 @@ tostruct_in_a6(ARGS_TOSTRUCT) {
 	dns_name_t name;
 	isc_region_t r;
 
-	REQUIRE(rdata->type == 38);
-	REQUIRE(rdata->rdclass == 1);
+	REQUIRE(rdata->type == dns_rdatatype_a6);
+	REQUIRE(rdata->rdclass == dns_rdataclass_in);
 	REQUIRE(target != NULL);
 	REQUIRE(rdata->length != 0);
 
@@ -347,7 +347,7 @@ tostruct_in_a6(ARGS_TOSTRUCT) {
 	if (a6->prefixlen != 128) {
 		octets = 16 - a6->prefixlen / 8;
 		INSIST(r.length >= octets);
-		memcpy(a6->in6_addr.s6_addr + 16 - octets, r.base, octets);
+		memmove(a6->in6_addr.s6_addr + 16 - octets, r.base, octets);
 		isc_region_consume(&r, octets);
 	}
 
@@ -369,8 +369,8 @@ freestruct_in_a6(ARGS_FREESTRUCT) {
 	dns_rdata_in_a6_t *a6 = source;
 
 	REQUIRE(source != NULL);
-	REQUIRE(a6->common.rdclass == 1);
-	REQUIRE(a6->common.rdtype == 38);
+	REQUIRE(a6->common.rdclass == dns_rdataclass_in);
+	REQUIRE(a6->common.rdtype == dns_rdatatype_a6);
 
 	if (a6->mctx == NULL)
 		return;
@@ -382,8 +382,8 @@ freestruct_in_a6(ARGS_FREESTRUCT) {
 
 static inline isc_result_t
 additionaldata_in_a6(ARGS_ADDLDATA) {
-	REQUIRE(rdata->type == 38);
-	REQUIRE(rdata->rdclass == 1);
+	REQUIRE(rdata->type == dns_rdatatype_a6);
+	REQUIRE(rdata->rdclass == dns_rdataclass_in);
 
 	UNUSED(rdata);
 	UNUSED(add);
@@ -399,8 +399,8 @@ digest_in_a6(ARGS_DIGEST) {
 	isc_result_t result;
 	dns_name_t name;
 
-	REQUIRE(rdata->type == 38);
-	REQUIRE(rdata->rdclass == 1);
+	REQUIRE(rdata->type == dns_rdatatype_a6);
+	REQUIRE(rdata->rdclass == dns_rdataclass_in);
 
 	dns_rdata_toregion(rdata, &r1);
 	r2 = r1;
@@ -423,8 +423,8 @@ digest_in_a6(ARGS_DIGEST) {
 static inline isc_boolean_t
 checkowner_in_a6(ARGS_CHECKOWNER) {
 
-	REQUIRE(type == 38);
-	REQUIRE(rdclass == 1);
+	REQUIRE(type == dns_rdatatype_a6);
+	REQUIRE(rdclass == dns_rdataclass_in);
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -438,8 +438,8 @@ checknames_in_a6(ARGS_CHECKNAMES) {
 	dns_name_t name;
 	unsigned int prefixlen;
 
-	REQUIRE(rdata->type == 38);
-	REQUIRE(rdata->rdclass == 1);
+	REQUIRE(rdata->type == dns_rdatatype_a6);
+	REQUIRE(rdata->rdclass == dns_rdataclass_in);
 
 	UNUSED(owner);
 
