@@ -773,8 +773,8 @@ ATF_TC_BODY(edns_client_subnet, tc) {
 		/*
 		 * Option code family 0, source 0, scope 0.
 		 */
-		WIRE_INVALID(0x00, 0x08, 0x00, 0x04,
-			     0x00, 0x00, 0x00, 0x00),
+		WIRE_VALID(0x00, 0x08, 0x00, 0x04,
+			   0x00, 0x00, 0x00, 0x00),
 		/*
 		 * Option code family 1 (IPv4), source 0, scope 0.
 		 */
@@ -822,11 +822,22 @@ ATF_TC_BODY(edns_client_subnet, tc) {
 			     0x00, 0x00, 0x00, 0x00,
 			     0x00, 0x00, 0x00, 0x00),
 		/*
-		 * Length too short for source generic.
+		 * When family=0, source and scope should be 0.
+		 */
+		WIRE_VALID(0x00, 0x08, 0x00,    4,
+			   0x00, 0x00, 0x00, 0x00),
+		/*
+		 * When family=0, source and scope should be 0.
 		 */
 		WIRE_INVALID(0x00, 0x08, 0x00,    5,
-			     0x00, 0x00,   17, 0x00,
-			     0x00, 0x00),
+			     0x00, 0x00, 0x01, 0x00,
+			     0x00),
+		/*
+		 * When family=0, source and scope should be 0.
+		 */
+		WIRE_INVALID(0x00, 0x08, 0x00,    5,
+			     0x00, 0x00, 0x00, 0x01,
+			     0x00),
 		/*
 		 * Length too short for source IPv4.
 		 */
