@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -148,7 +148,7 @@ thread_key_mutex_init(void) {
 }
 
 static isc_result_t
-thread_key_init() {
+thread_key_init(void) {
 	isc_result_t result;
 
 	result = isc_once_do(&once, thread_key_mutex_init);
