@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005, 2007, 2008, 2015, 2017  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -14,7 +14,7 @@
  * PERFORMANCE OF THIS SOFTWARE.
  */
 
-/* $Id: atomic.h,v 1.10 2008/01/24 23:47:00 tbox Exp $ */
+/* $Id: atomic.h,v 1.6 2008/01/24 23:47:00 tbox Exp $ */
 
 #ifndef ISC_ATOMIC_H
 #define ISC_ATOMIC_H 1
@@ -23,150 +23,89 @@
 #include <isc/types.h>
 
 #ifdef ISC_PLATFORM_USEGCCASM
-/*
- * This routine atomically increments the value stored in 'p' by 'val', and
- * returns the previous value.
- */
-static __inline__ isc_int32_t
-isc_atomic_xadd(isc_int32_t *p, isc_int32_t val) {
-	isc_int32_t prev = val;
 
-	__asm__ volatile(
-#ifdef ISC_PLATFORM_USETHREADS
-		"lock;"
-#endif
-		"xadd %0, %1"
-		:"=q"(prev)
-		:"m"(*p), "0"(prev)
-		:"memory", "cc");
-
-	return (prev);
-}
-
-#ifdef ISC_PLATFORM_HAVEXADDQ
-static __inline__ isc_int64_t
-isc_atomic_xaddq(isc_int64_t *p, isc_int64_t val) {
-	isc_int64_t prev = val;
-
-	__asm__ volatile(
-#ifdef ISC_PLATFORM_USETHREADS
-	    "lock;"
-#endif
-	    "xaddq %0, %1"
-	    :"=q"(prev)
-	    :"m"(*p), "0"(prev)
-	    :"memory", "cc");
-
-	return (prev);
-}
-#endif /* ISC_PLATFORM_HAVEXADDQ */
-
-/*
- * This routine atomically stores the value 'val' in 'p' (32-bit version).
- */
-static __inline__ void
-isc_atomic_store(isc_int32_t *p, isc_int32_t val) {
-	__asm__ volatile(
-#ifdef ISC_PLATFORM_USETHREADS
-		/*
-		 * xchg should automatically lock memory, but we add it
-		 * explicitly just in case (it at least doesn't harm)
-		 */
-		"lock;"
-#endif
-
-		"xchgl %1, %0"
-		:
-		: "r"(val), "m"(*p)
-		: "memory");
-}
-
-#ifdef ISC_PLATFORM_HAVEATOMICSTOREQ
-/*
- * This routine atomically stores the value 'val' in 'p' (64-bit version).
- */
-static __inline__ void
-isc_atomic_storeq(isc_int64_t *p, isc_int64_t val) {
-	__asm__ volatile(
-#ifdef ISC_PLATFORM_USETHREADS
-		/*
-		 * xchg should automatically lock memory, but we add it
-		 * explicitly just in case (it at least doesn't harm)
-		 */
-		"lock;"
-#endif
-
-		"xchgq %1, %0"
-		:
-		: "r"(val), "m"(*p)
-		: "memory");
-}
-#endif /* ISC_PLATFORM_HAVEATOMICSTOREQ */
-
-/*
- * This routine atomically replaces the value in 'p' with 'val', if the
- * original value is equal to 'cmpval'.  The original value is returned in any
- * case.
- */
-static __inline__ isc_int32_t
-isc_atomic_cmpxchg(isc_int32_t *p, isc_int32_t cmpval, isc_int32_t val) {
-	__asm__ volatile(
-#ifdef ISC_PLATFORM_USETHREADS
-		"lock;"
-#endif
-		"cmpxchgl %1, %2"
-		: "=a"(cmpval)
-		: "r"(val), "m"(*p), "a"(cmpval)
-		: "memory");
-
-	return (cmpval);
-}
+/* We share the gcc-version with x86_32 */
+#error "impossible case.  check build configuration"
 
 #elif defined(ISC_PLATFORM_USESTDASM)
 /*
  * The followings are "generic" assembly code which implements the same
  * functionality in case the gcc extension cannot be used.  It should be
  * better to avoid inlining below, since we directly refer to specific
- * positions of the stack frame, which would not actually point to the
- * intended address in the embedded mnemonic.
+ * registers for arguments, which would not actually correspond to the
+ * intended address or value in the embedded mnemonic.
  */
+
 static isc_int32_t
 isc_atomic_xadd(isc_int32_t *p, isc_int32_t val) {
 	(void)(p);
 	(void)(val);
 
 	__asm (
-		"movl 8(%ebp), %ecx\n"
-		"movl 12(%ebp), %edx\n"
+		"movq %rdi, %rdx\n"
+		"movl %esi, %eax\n"
 #ifdef ISC_PLATFORM_USETHREADS
 		"lock;"
 #endif
-		"xadd %edx, (%ecx)\n"
-
+		"xadd %eax, (%rdx)\n"
 		/*
-		 * set the return value directly in the register so that we
-		 * can avoid guessing the correct position in the stack for a
-		 * local variable.
+		 * XXX: assume %eax will be used as the return value.
 		 */
-		"movl %edx, %eax"
 		);
 }
 
+#ifdef ISC_PLATFORM_HAVEXADDQ
+static isc_int64_t
+isc_atomic_xaddq(isc_int64_t *p, isc_int64_t val) {
+	(void)(p);
+	(void)(val);
+
+	__asm (
+		"movq %rdi, %rdx\n"
+		"movq %rsi, %rax\n"
+#ifdef ISC_PLATFORM_USETHREADS
+		"lock;"
+#endif
+		"xaddq %rax, (%rdx)\n"
+		/*
+		 * XXX: assume %rax will be used as the return value.
+		 */
+		);
+}
+#endif
+
 static void
 isc_atomic_store(isc_int32_t *p, isc_int32_t val) {
 	(void)(p);
 	(void)(val);
 
 	__asm (
-		"movl 8(%ebp), %ecx\n"
-		"movl 12(%ebp), %edx\n"
+		"movq %rdi, %rax\n"
+		"movl %esi, %edx\n"
 #ifdef ISC_PLATFORM_USETHREADS
 		"lock;"
 #endif
-		"xchgl (%ecx), %edx\n"
+		"xchgl (%rax), %edx\n"
 		);
 }
 
+#ifdef ISC_PLATFORM_HAVEATOMICSTOREQ
+static void
+isc_atomic_storeq(isc_int64_t *p, isc_int64_t val) {
+	(void)(p);
+	(void)(val);
+
+	__asm (
+		"movq %rdi, %rax\n"
+		"movq %rsi, %rdx\n"
+#ifdef ISC_PLATFORM_USETHREADS
+		"lock;"
+#endif
+		"xchgq (%rax), %rdx\n"
+		);
+}
+#endif
+
 static isc_int32_t
 isc_atomic_cmpxchg(isc_int32_t *p, isc_int32_t cmpval, isc_int32_t val) {
 	(void)(p);
@@ -174,20 +113,28 @@ isc_atomic_cmpxchg(isc_int32_t *p, isc_int32_t cmpval, isc_int32_t val) {
 	(void)(val);
 
 	__asm (
-		"movl 8(%ebp), %ecx\n"
-		"movl 12(%ebp), %eax\n"	/* must be %eax for cmpxchgl */
-		"movl 16(%ebp), %edx\n"
+		/*
+		 * p is %rdi, cmpval is %esi, val is %edx.
+		 */
+		"movl %edx, %ecx\n"
+		"movl %esi, %eax\n"
+		"movq %rdi, %rdx\n"
+
 #ifdef ISC_PLATFORM_USETHREADS
 		"lock;"
 #endif
-
 		/*
-		 * If (%ecx) == %eax then (%ecx) := %edx.
-		 % %eax is set to old (%ecx), which will be the return value.
+		 * If [%rdi] == %eax then [%rdi] := %ecx (equal to %edx
+		 * from above), and %eax is untouched (equal to %esi)
+		 * from above.
+		 *
+		 * Else if [%rdi] != %eax then [%rdi] := [%rdi]
+		 * (rewritten in write cycle) and %eax := [%rdi].
 		 */
-		"cmpxchgl %edx, (%ecx)"
+		"cmpxchgl %ecx, (%rdx)"
 		);
 }
+
 #else /* !ISC_PLATFORM_USEGCCASM && !ISC_PLATFORM_USESTDASM */
 
 #error "unsupported compiler.  disable atomic ops by --disable-atomic"
